{% if data.errors %}
    <p class="text-danger">
        Uncaught error(s) executing scan
        <a href="/errors/{{data.uid}}" target="_blank">View details</a>
    </p>
{% endif %}
<div class="table-container submodule" id="ip-table-container">
    <table class="table table-bordered table-striped">
        <thead>
            <tr>
                <th class="detail-col" scope="col"></th>
                <th class="ip" scope="col">IP / <span class="alt">Host</span></th>
                <th class="mac" scope="col">MAC / <span class="alt">Manufacturer</span></th>
                <th class="ports" scope="col">Open Ports</th>
                <th class="stage" scope="col">Stage</th>
            </tr>
        </thead>
        <tbody>
        {% for device in data.devices %}
            {% if device | is_substring_in_values(filter) %}
                {% include 'scan/ip-table-row.html' %}
            {% endif %}
        {% endfor %}
        </tbody>
    </table>
</div>
